@@ -29,6 +29,8 @@ enum generic
     Generic_Format_Commercial_IfAny,
     Generic_Format_Version,
     Generic_Format_Profile,
+    Generic_Format_Level,
+    Generic_Format_Tier,
     Generic_Format_Compression,
     Generic_Format_Settings,
     Generic_InternetMediaType,
@@ -217,6 +219,7 @@ enum general
     General_Format_Commercial_IfAny,
     General_Format_Version,
     General_Format_Profile,
+    General_Format_Level,
     General_Format_Compression,
     General_Format_Settings,
     General_InternetMediaType,
@@ -353,6 +356,7 @@ enum general
     General_Accompaniment,
     General_Composer,
     General_Composer_Nationality,
+    General_Composer_Sort,
     General_Arranger,
     General_Lyricist,
     General_Original_Lyricist,
@@ -387,6 +391,7 @@ enum general
     General_Publisher_URL,
     General_Label,
     General_Genre,
+    General_PodcastCategory,
     General_Mood,
     General_ContentType,
     General_Subject,
@@ -503,6 +508,8 @@ enum video
     Video_Format_Commercial_IfAny,
     Video_Format_Version,
     Video_Format_Profile,
+    Video_Format_Level,
+    Video_Format_Tier,
     Video_Format_Compression,
     Video_MultiView_BaseProfile,
     Video_MultiView_Count,
@@ -791,6 +798,8 @@ enum video
     Video_Language_String3,
     Video_Language_String4,
     Video_Language_More,
+    Video_ServiceKind,
+    Video_ServiceKind_String,
     Video_Disabled,
     Video_Disabled_String,
     Video_Default,
@@ -842,6 +851,7 @@ enum audio
     Audio_Format_Commercial_IfAny,
     Audio_Format_Version,
     Audio_Format_Profile,
+    Audio_Format_Level,
     Audio_Format_Compression,
     Audio_Format_Settings,
     Audio_Format_Settings_SBR,
@@ -1078,6 +1088,8 @@ enum audio
     Audio_Language_String3,
     Audio_Language_String4,
     Audio_Language_More,
+    Audio_ServiceKind,
+    Audio_ServiceKind_String,
     Audio_Disabled,
     Audio_Disabled_String,
     Audio_Default,
@@ -1316,6 +1328,8 @@ enum text
     Text_Language_String3,
     Text_Language_String4,
     Text_Language_More,
+    Text_ServiceKind,
+    Text_ServiceKind_String,
     Text_Disabled,
     Text_Disabled_String,
     Text_Default,
@@ -1382,6 +1396,41 @@ enum other
     Other_FrameRate_Num,
     Other_FrameRate_Den,
     Other_FrameCount,
+    Other_Delay,
+    Other_Delay_String,
+    Other_Delay_String1,
+    Other_Delay_String2,
+    Other_Delay_String3,
+    Other_Delay_String4,
+    Other_Delay_String5,
+    Other_Delay_Settings,
+    Other_Delay_DropFrame,
+    Other_Delay_Source,
+    Other_Delay_Source_String,
+    Other_Delay_Original,
+    Other_Delay_Original_String,
+    Other_Delay_Original_String1,
+    Other_Delay_Original_String2,
+    Other_Delay_Original_String3,
+    Other_Delay_Original_String4,
+    Other_Delay_Original_String5,
+    Other_Delay_Original_Settings,
+    Other_Delay_Original_DropFrame,
+    Other_Delay_Original_Source,
+    Other_Video_Delay,
+    Other_Video_Delay_String,
+    Other_Video_Delay_String1,
+    Other_Video_Delay_String2,
+    Other_Video_Delay_String3,
+    Other_Video_Delay_String4,
+    Other_Video_Delay_String5,
+    Other_Video0_Delay,
+    Other_Video0_Delay_String,
+    Other_Video0_Delay_String1,
+    Other_Video0_Delay_String2,
+    Other_Video0_Delay_String3,
+    Other_Video0_Delay_String4,
+    Other_Video0_Delay_String5,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
     Other_TimeStamp_FirstFrame_String1,
@@ -1401,6 +1450,8 @@ enum other
     Other_Language_String3,
     Other_Language_String4,
     Other_Language_More,
+    Other_ServiceKind,
+    Other_ServiceKind_String,
     Other_Disabled,
     Other_Disabled_String,
     Other_Default,
@@ -1512,6 +1563,8 @@ enum image
     Image_Language_String3,
     Image_Language_String4,
     Image_Language_More,
+    Image_ServiceKind,
+    Image_ServiceKind_String,
     Image_Disabled,
     Image_Disabled_String,
     Image_Default,
@@ -1605,6 +1658,8 @@ enum menu
     Menu_Language_String3,
     Menu_Language_String4,
     Menu_Language_More,
+    Menu_ServiceKind,
+    Menu_ServiceKind_String,
     Menu_ServiceName,
     Menu_ServiceChannel,
     Menu_Service_Url,
